@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # File: opsgenielib.py
 #
-# Copyright 2019 Yorick Hoorneman
+# Copyright 2023 Yorick Hoorneman
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to
@@ -27,12 +27,12 @@
 Main code for opsgenielib.
 
 .. _Google Python Style Guide:
-   http://google.github.io/styleguide/pyguide.html
+   https://google.github.io/styleguide/pyguide.html
 
 """
 
-import logging
 import json
+import logging
 import urllib.parse
 from datetime import datetime, timedelta
 
@@ -43,8 +43,8 @@ from opsgenielib.opsgenielibexceptions import InvalidApiKey
 
 __author__ = '''Yorick Hoorneman <yhoorneman@schubergphilis.com>'''
 __docformat__ = '''google'''
-__date__ = '''12-04-2019'''
-__copyright__ = '''Copyright 2019, Yorick Hoorneman'''
+__date__ = '''21-03-2023'''
+__copyright__ = '''Copyright 2023, Yorick Hoorneman'''
 __credits__ = ["Yorick Hoorneman"]
 __license__ = '''MIT'''
 __maintainer__ = '''Yorick Hoorneman'''
@@ -57,7 +57,6 @@ LOGGER_BASENAME = '''opsgenielib'''
 LOGGER = logging.getLogger(LOGGER_BASENAME)
 LOGGER.addHandler(logging.NullHandler())
 
-
 class Team:
     """Models the team."""
 
@@ -68,15 +67,19 @@ class Team:
 
     @property
     def id(self):  # pylint: disable=invalid-name, missing-docstring
-        return self._data.get('id')
+        return self._data.get('data', {}).get('id', {})
 
     @property
     def description(self):  # pylint: disable=missing-docstring
-        return self._data.get('description')
+        return self._data.get('data', {}).get('description', {})
 
     @property
     def name(self):  # pylint: disable=missing-docstring
-        return self._data.get('name')
+        return self._data.get('data', {}).get('name', {})
+
+    @property
+    def members(self):  # pylint: disable=missing-docstring
+        return self._data.get('data', {}).get('members', {})
 
     def __str__(self):
         return (f'Team name: {self.name}\n'
@@ -95,7 +98,7 @@ class Team:
         if not response.ok:
             self._logger.error('Request failed %s', response.status_code)
             response.raise_for_status()
-        return response.json()
+        return [Integration(self, integration) for integration in response.json().get('data', {})]
 
 
 class Integration:
@@ -205,19 +208,19 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         """Creation of a maintenance policy for a specified schedule. Returns the json."""
         url = f'{self._base_url}/v1/maintenance'
         payload = {
-            "teamId": f"{team_id}",
-            "description": f"{description}",
+            "teamId": team_id,
+            "description": description,
             "time": {
                 "type": "schedule",
-                "startDate": f"{start_date}",
-                "endDate": f"{end_date}"
+                "startDate": start_date,
+                "endDate": end_date
             },
             "rules": [
                 {
-                    "state": f"{state}",
+                    "state": state,
                     "entity": {
-                        "id": f"{rules_id}",
-                        "type": f"{rules_type}"
+                        "id": rules_id,
+                        "type": rules_type
                     }
                 }
             ]
@@ -466,6 +469,46 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         response.raise_for_status()
         return [Integration(self, data) for data in response.json().get('data')]
 
+    def get_integration_actions(self, id_):
+        """Get information about the actions (create/close/acknowledge) side of the integration."""
+        url = f'{self._integrations_url}/{id_}/actions'
+        self._logger.debug('Making a call to "%s"', url)
+        response = self._session.get(url)
+        response.raise_for_status()
+        return response.json()
+
+    def create_integration_action(self, id_, type_, name, alias, order, user, filter_condition_match_type, filter_conditions, source, message, description, entity, tags, extra_properties, responders=None, note=''):
+        """Create an alert action (create/close/acknowledge) for an existing integration."""
+        url = f'{self._integrations_url}/{id_}/actions'
+        payload = {
+            "type": type_,
+            "name": name,
+            "order": order,
+            "filter": {
+                "conditionMatchType": filter_condition_match_type,
+                "conditions": filter_conditions
+            },
+            "user": user,
+            "note": note,
+            "alias": alias,
+            "source": source,
+            "message": message,
+            "description": description,
+            "entity": entity,
+            "appendAttachments": True,
+            "alertActions": [],
+            "ignoreAlertActionsFromPayload": False,
+            "ignoreRespondersFromPayload": False,
+            "ignoreTeamsFromPayload": False,
+            "tags": tags,
+            "ignoreTagsFromPayload": False,
+            "extraProperties": extra_properties,
+            "ignoreExtraPropertiesFromPayload": False
+        }
+        self._logger.debug('Making a call to "%s"', url)
+        response = self._session.post(url, json=payload)
+        return response.json()
+
     def get_integration_by_id(self, id_):
         """Get information about an integration based on the ID of the integration."""
         url = f'{self._integrations_url}/{id_}'
@@ -520,7 +563,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         self._logger.debug('Making a call to "%s"', url)
         response = self._session.get(url)
         response.raise_for_status()
-        return response.json()
+        return Team(self, response.json())
 
     def get_team_by_name(self, team_name):
         """Get information about a team based on teamname."""
@@ -528,7 +571,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         self._logger.debug('Making a call to "%s"', url)
         response = self._session.get(url)
         response.raise_for_status()
-        return response.json()
+        return Team(self, response.json())
 
     def list_teams(self):
         """Listing all team names and their ID's."""
@@ -536,7 +579,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         self._logger.debug('Making a call to "%s"', url)
         response = self._session.get(url)
         response.raise_for_status()
-        return response.json()
+        return [Team(self, data) for data in response.json().get('data')]
 
     def get_team_logs_by_id(self, id_):
         """Get the log of changes made within the opsgenie team, based on team id."""
@@ -745,18 +788,14 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         Note: Start and End date format example: 2019-03-15T14:34:09Z.
         opsgenie uses UTC, time entered might be different.
         """
-        start = datetime.strptime(start_date, "%Y-%m-%dT%H:%M:%SZ")
-        end = datetime.strptime(end_date, "%Y-%m-%dT%H:%M:%SZ")
-        start_date_utc = start.astimezone(pytz.utc).strftime("%Y-%m-%dT%H:%M:%SZ")
-        end_date_utc = end.astimezone(pytz.utc).strftime("%Y-%m-%dT%H:%M:%SZ")
         url = f'{self._schedules_url}/{team_name}/overrides?scheduleIdentifierType=name'
         payload = {
             "user": {
                 "type": "user",
                 "username": f"{user}"
             },
-            "startDate": f"{start_date_utc}",
-            "endDate": f"{end_date_utc}"
+            "startDate": f"{start_date}",
+            "endDate": f"{end_date}"
         }
         self._logger.debug('Making a call to "%s"', url)
         response = self._session.post(url, json=payload)
